module.exports = {
	"0.20.0": "39.0.2171.65",
	"0.20.1": "39.0.2171.65",
	"0.20.2": "39.0.2171.65",
	"0.20.3": "39.0.2171.65",
	"0.20.4": "39.0.2171.65",
	"0.20.5": "39.0.2171.65",
	"0.20.6": "39.0.2171.65",
	"0.20.7": "39.0.2171.65",
	"0.20.8": "39.0.2171.65",
	"0.21.0": "40.0.2214.91",
	"0.21.1": "40.0.2214.91",
	"0.21.2": "40.0.2214.91",
	"0.21.3": "41.0.2272.76",
	"0.22.1": "41.0.2272.76",
	"0.22.2": "41.0.2272.76",
	"0.22.3": "41.0.2272.76",
	"0.23.0": "41.0.2272.76",
	"0.24.0": "41.0.2272.76",
	"0.25.0": "42.0.2311.107",
	"0.25.1": "42.0.2311.107",
	"0.25.2": "42.0.2311.107",
	"0.25.3": "42.0.2311.107",
	"0.26.0": "42.0.2311.107",
	"0.26.1": "42.0.2311.107",
	"0.27.0": "42.0.2311.107",
	"0.27.1": "42.0.2311.107",
	"0.27.2": "43.0.2357.65",
	"0.27.3": "43.0.2357.65",
	"0.28.0": "43.0.2357.65",
	"0.28.1": "43.0.2357.65",
	"0.28.2": "43.0.2357.65",
	"0.28.3": "43.0.2357.65",
	"0.29.1": "43.0.2357.65",
	"0.29.2": "43.0.2357.65",
	"0.30.4": "44.0.2403.125",
	"0.31.0": "44.0.2403.125",
	"0.31.2": "45.0.2454.85",
	"0.32.2": "45.0.2454.85",
	"0.32.3": "45.0.2454.85",
	"0.33.0": "45.0.2454.85",
	"0.33.1": "45.0.2454.85",
	"0.33.2": "45.0.2454.85",
	"0.33.3": "45.0.2454.85",
	"0.33.4": "45.0.2454.85",
	"0.33.6": "45.0.2454.85",
	"0.33.7": "45.0.2454.85",
	"0.33.8": "45.0.2454.85",
	"0.33.9": "45.0.2454.85",
	"0.34.0": "45.0.2454.85",
	"0.34.1": "45.0.2454.85",
	"0.34.2": "45.0.2454.85",
	"0.34.3": "45.0.2454.85",
	"0.34.4": "45.0.2454.85",
	"0.35.1": "45.0.2454.85",
	"0.35.2": "45.0.2454.85",
	"0.35.3": "45.0.2454.85",
	"0.35.4": "45.0.2454.85",
	"0.35.5": "45.0.2454.85",
	"0.36.0": "47.0.2526.73",
	"0.36.2": "47.0.2526.73",
	"0.36.3": "47.0.2526.73",
	"0.36.4": "47.0.2526.73",
	"0.36.5": "47.0.2526.110",
	"0.36.6": "47.0.2526.110",
	"0.36.7": "47.0.2526.110",
	"0.36.8": "47.0.2526.110",
	"0.36.9": "47.0.2526.110",
	"0.36.10": "47.0.2526.110",
	"0.36.11": "47.0.2526.110",
	"0.36.12": "47.0.2526.110",
	"0.37.0": "49.0.2623.75",
	"0.37.1": "49.0.2623.75",
	"0.37.3": "49.0.2623.75",
	"0.37.4": "49.0.2623.75",
	"0.37.5": "49.0.2623.75",
	"0.37.6": "49.0.2623.75",
	"0.37.7": "49.0.2623.75",
	"0.37.8": "49.0.2623.75",
	"1.0.0": "49.0.2623.75",
	"1.0.1": "49.0.2623.75",
	"1.0.2": "49.0.2623.75",
	"1.1.0": "50.0.2661.102",
	"1.1.1": "50.0.2661.102",
	"1.1.2": "50.0.2661.102",
	"1.1.3": "50.0.2661.102",
	"1.2.0": "51.0.2704.63",
	"1.2.1": "51.0.2704.63",
	"1.2.2": "51.0.2704.84",
	"1.2.3": "51.0.2704.84",
	"1.2.4": "51.0.2704.103",
	"1.2.5": "51.0.2704.103",
	"1.2.6": "51.0.2704.106",
	"1.2.7": "51.0.2704.106",
	"1.2.8": "51.0.2704.106",
	"1.3.0": "52.0.2743.82",
	"1.3.1": "52.0.2743.82",
	"1.3.2": "52.0.2743.82",
	"1.3.3": "52.0.2743.82",
	"1.3.4": "52.0.2743.82",
	"1.3.5": "52.0.2743.82",
	"1.3.6": "52.0.2743.82",
	"1.3.7": "52.0.2743.82",
	"1.3.9": "52.0.2743.82",
	"1.3.10": "52.0.2743.82",
	"1.3.13": "52.0.2743.82",
	"1.3.14": "52.0.2743.82",
	"1.3.15": "52.0.2743.82",
	"1.4.0": "53.0.2785.113",
	"1.4.1": "53.0.2785.113",
	"1.4.2": "53.0.2785.113",
	"1.4.3": "53.0.2785.113",
	"1.4.4": "53.0.2785.113",
	"1.4.5": "53.0.2785.113",
	"1.4.6": "53.0.2785.143",
	"1.4.7": "53.0.2785.143",
	"1.4.8": "53.0.2785.143",
	"1.4.10": "53.0.2785.143",
	"1.4.11": "53.0.2785.143",
	"1.4.12": "54.0.2840.51",
	"1.4.13": "53.0.2785.143",
	"1.4.14": "53.0.2785.143",
	"1.4.15": "53.0.2785.143",
	"1.4.16": "53.0.2785.143",
	"1.5.0": "54.0.2840.101",
	"1.5.1": "54.0.2840.101",
	"1.6.0": "56.0.2924.87",
	"1.6.1": "56.0.2924.87",
	"1.6.2": "56.0.2924.87",
	"1.6.3": "56.0.2924.87",
	"1.6.4": "56.0.2924.87",
	"1.6.5": "56.0.2924.87",
	"1.6.6": "56.0.2924.87",
	"1.6.7": "56.0.2924.87",
	"1.6.8": "56.0.2924.87",
	"1.6.9": "56.0.2924.87",
	"1.6.10": "56.0.2924.87",
	"1.6.11": "56.0.2924.87",
	"1.6.12": "56.0.2924.87",
	"1.6.13": "56.0.2924.87",
	"1.6.14": "56.0.2924.87",
	"1.6.15": "56.0.2924.87",
	"1.6.16": "56.0.2924.87",
	"1.6.17": "56.0.2924.87",
	"1.6.18": "56.0.2924.87",
	"1.7.0": "58.0.3029.110",
	"1.7.1": "58.0.3029.110",
	"1.7.2": "58.0.3029.110",
	"1.7.3": "58.0.3029.110",
	"1.7.4": "58.0.3029.110",
	"1.7.5": "58.0.3029.110",
	"1.7.6": "58.0.3029.110",
	"1.7.7": "58.0.3029.110",
	"1.7.8": "58.0.3029.110",
	"1.7.9": "58.0.3029.110",
	"1.7.10": "58.0.3029.110",
	"1.7.11": "58.0.3029.110",
	"1.7.12": "58.0.3029.110",
	"1.7.13": "58.0.3029.110",
	"1.7.14": "58.0.3029.110",
	"1.7.15": "58.0.3029.110",
	"1.7.16": "58.0.3029.110",
	"1.8.0": "59.0.3071.115",
	"1.8.1": "59.0.3071.115",
	"1.8.2-beta.1": "59.0.3071.115",
	"1.8.2-beta.2": "59.0.3071.115",
	"1.8.2-beta.3": "59.0.3071.115",
	"1.8.2-beta.4": "59.0.3071.115",
	"1.8.2-beta.5": "59.0.3071.115",
	"1.8.2": "59.0.3071.115",
	"1.8.3": "59.0.3071.115",
	"1.8.4": "59.0.3071.115",
	"1.8.5": "59.0.3071.115",
	"1.8.6": "59.0.3071.115",
	"1.8.7": "59.0.3071.115",
	"1.8.8": "59.0.3071.115",
	"2.0.0-beta.1": "61.0.3163.100",
	"2.0.0-beta.2": "61.0.3163.100",
	"2.0.0-beta.3": "61.0.3163.100",
	"2.0.0-beta.4": "61.0.3163.100",
	"2.0.0-beta.5": "61.0.3163.100",
	"2.0.0-beta.6": "61.0.3163.100",
	"2.0.0-beta.7": "61.0.3163.100",
	"2.0.0-beta.8": "61.0.3163.100",
	"2.0.0": "61.0.3163.100",
	"2.0.1": "61.0.3163.100",
	"2.0.2": "61.0.3163.100",
	"2.0.3": "61.0.3163.100",
	"2.0.4": "61.0.3163.100",
	"2.0.5": "61.0.3163.100",
	"2.0.6": "61.0.3163.100",
	"2.0.7": "61.0.3163.100",
	"2.0.8-nightly.20180819": "61.0.3163.100",
	"2.0.8-nightly.20180820": "61.0.3163.100",
	"2.0.8": "61.0.3163.100",
	"2.0.9": "61.0.3163.100",
	"2.0.10": "61.0.3163.100",
	"2.0.11": "61.0.3163.100",
	"2.0.12": "61.0.3163.100",
	"2.0.13": "61.0.3163.100",
	"2.0.14": "61.0.3163.100",
	"2.0.15": "61.0.3163.100",
	"2.0.16": "61.0.3163.100",
	"2.0.17": "61.0.3163.100",
	"2.0.18": "61.0.3163.100",
	"2.1.0-unsupported.20180809": "61.0.3163.100",
	"3.0.0-beta.1": "66.0.3359.181",
	"3.0.0-beta.2": "66.0.3359.181",
	"3.0.0-beta.3": "66.0.3359.181",
	"3.0.0-beta.4": "66.0.3359.181",
	"3.0.0-beta.5": "66.0.3359.181",
	"3.0.0-beta.6": "66.0.3359.181",
	"3.0.0-beta.7": "66.0.3359.181",
	"3.0.0-beta.8": "66.0.3359.181",
	"3.0.0-beta.9": "66.0.3359.181",
	"3.0.0-beta.10": "66.0.3359.181",
	"3.0.0-beta.11": "66.0.3359.181",
	"3.0.0-beta.12": "66.0.3359.181",
	"3.0.0-beta.13": "66.0.3359.181",
	"3.0.0-nightly.20180818": "66.0.3359.181",
	"3.0.0-nightly.20180821": "66.0.3359.181",
	"3.0.0-nightly.20180823": "66.0.3359.181",
	"3.0.0-nightly.20180904": "66.0.3359.181",
	"3.0.0": "66.0.3359.181",
	"3.0.1": "66.0.3359.181",
	"3.0.2": "66.0.3359.181",
	"3.0.3": "66.0.3359.181",
	"3.0.4": "66.0.3359.181",
	"3.0.5": "66.0.3359.181",
	"3.0.6": "66.0.3359.181",
	"3.0.7": "66.0.3359.181",
	"3.0.8": "66.0.3359.181",
	"3.0.9": "66.0.3359.181",
	"3.0.10": "66.0.3359.181",
	"3.0.11": "66.0.3359.181",
	"3.0.12": "66.0.3359.181",
	"3.0.13": "66.0.3359.181",
	"3.0.14": "66.0.3359.181",
	"3.0.15": "66.0.3359.181",
	"3.0.16": "66.0.3359.181",
	"3.1.0-beta.1": "66.0.3359.181",
	"3.1.0-beta.2": "66.0.3359.181",
	"3.1.0-beta.3": "66.0.3359.181",
	"3.1.0-beta.4": "66.0.3359.181",
	"3.1.0-beta.5": "66.0.3359.181",
	"3.1.0": "66.0.3359.181",
	"3.1.1": "66.0.3359.181",
	"3.1.2": "66.0.3359.181",
	"3.1.3": "66.0.3359.181",
	"3.1.4": "66.0.3359.181",
	"3.1.5": "66.0.3359.181",
	"3.1.6": "66.0.3359.181",
	"3.1.7": "66.0.3359.181",
	"3.1.8": "66.0.3359.181",
	"3.1.9": "66.0.3359.181",
	"3.1.10": "66.0.3359.181",
	"3.1.11": "66.0.3359.181",
	"3.1.12": "66.0.3359.181",
	"3.1.13": "66.0.3359.181",
	"4.0.0-beta.1": "69.0.3497.106",
	"4.0.0-beta.2": "69.0.3497.106",
	"4.0.0-beta.3": "69.0.3497.106",
	"4.0.0-beta.4": "69.0.3497.106",
	"4.0.0-beta.5": "69.0.3497.106",
	"4.0.0-beta.6": "69.0.3497.106",
	"4.0.0-beta.7": "69.0.3497.106",
	"4.0.0-beta.8": "69.0.3497.106",
	"4.0.0-beta.9": "69.0.3497.106",
	"4.0.0-beta.10": "69.0.3497.106",
	"4.0.0-beta.11": "69.0.3497.106",
	"4.0.0-nightly.20180817": "66.0.3359.181",
	"4.0.0-nightly.20180819": "66.0.3359.181",
	"4.0.0-nightly.20180821": "66.0.3359.181",
	"4.0.0-nightly.20180929": "67.0.3396.99",
	"4.0.0-nightly.20181006": "68.0.3440.128",
	"4.0.0-nightly.20181010": "69.0.3497.106",
	"4.0.0": "69.0.3497.106",
	"4.0.1": "69.0.3497.106",
	"4.0.2": "69.0.3497.106",
	"4.0.3": "69.0.3497.106",
	"4.0.4": "69.0.3497.106",
	"4.0.5": "69.0.3497.106",
	"4.0.6": "69.0.3497.106",
	"4.0.7": "69.0.3497.128",
	"4.0.8": "69.0.3497.128",
	"4.1.0": "69.0.3497.128",
	"4.1.1": "69.0.3497.128",
	"4.1.2": "69.0.3497.128",
	"4.1.3": "69.0.3497.128",
	"4.1.4": "69.0.3497.128",
	"4.1.5": "69.0.3497.128",
	"4.2.0": "69.0.3497.128",
	"4.2.1": "69.0.3497.128",
	"4.2.2": "69.0.3497.128",
	"4.2.3": "69.0.3497.128",
	"4.2.4": "69.0.3497.128",
	"4.2.5": "69.0.3497.128",
	"4.2.6": "69.0.3497.128",
	"4.2.7": "69.0.3497.128",
	"4.2.8": "69.0.3497.128",
	"4.2.9": "69.0.3497.128",
	"4.2.10": "69.0.3497.128",
	"4.2.11": "69.0.3497.128",
	"4.2.12": "69.0.3497.128",
	"5.0.0-beta.1": "72.0.3626.52",
	"5.0.0-beta.2": "72.0.3626.52",
	"5.0.0-beta.3": "73.0.3683.27",
	"5.0.0-beta.4": "73.0.3683.54",
	"5.0.0-beta.5": "73.0.3683.61",
	"5.0.0-beta.6": "73.0.3683.84",
	"5.0.0-beta.7": "73.0.3683.94",
	"5.0.0-beta.8": "73.0.3683.104",
	"5.0.0-beta.9": "73.0.3683.117",
	"5.0.0-nightly.20190107": "70.0.3538.110",
	"5.0.0-nightly.20190121": "71.0.3578.98",
	"5.0.0-nightly.20190122": "71.0.3578.98",
	"5.0.0": "73.0.3683.119",
	"5.0.1": "73.0.3683.121",
	"5.0.2": "73.0.3683.121",
	"5.0.3": "73.0.3683.121",
	"5.0.4": "73.0.3683.121",
	"5.0.5": "73.0.3683.121",
	"5.0.6": "73.0.3683.121",
	"5.0.7": "73.0.3683.121",
	"5.0.8": "73.0.3683.121",
	"5.0.9": "73.0.3683.121",
	"5.0.10": "73.0.3683.121",
	"5.0.11": "73.0.3683.121",
	"5.0.12": "73.0.3683.121",
	"5.0.13": "73.0.3683.121",
	"6.0.0-beta.1": "76.0.3774.1",
	"6.0.0-beta.2": "76.0.3783.1",
	"6.0.0-beta.3": "76.0.3783.1",
	"6.0.0-beta.4": "76.0.3783.1",
	"6.0.0-beta.5": "76.0.3805.4",
	"6.0.0-beta.6": "76.0.3809.3",
	"6.0.0-beta.7": "76.0.3809.22",
	"6.0.0-beta.8": "76.0.3809.26",
	"6.0.0-beta.9": "76.0.3809.26",
	"6.0.0-beta.10": "76.0.3809.37",
	"6.0.0-beta.11": "76.0.3809.42",
	"6.0.0-beta.12": "76.0.3809.54",
	"6.0.0-beta.13": "76.0.3809.60",
	"6.0.0-beta.14": "76.0.3809.68",
	"6.0.0-beta.15": "76.0.3809.74",
	"6.0.0-nightly.20190212": "72.0.3626.107",
	"6.0.0-nightly.20190213": "72.0.3626.110",
	"6.0.0-nightly.20190311": "74.0.3724.8",
	"6.0.0": "76.0.3809.88",
	"6.0.1": "76.0.3809.102",
	"6.0.2": "76.0.3809.110",
	"6.0.3": "76.0.3809.126",
	"6.0.4": "76.0.3809.131",
	"6.0.5": "76.0.3809.136",
	"6.0.6": "76.0.3809.138",
	"6.0.7": "76.0.3809.139",
	"6.0.8": "76.0.3809.146",
	"6.0.9": "76.0.3809.146",
	"6.0.10": "76.0.3809.146",
	"6.0.11": "76.0.3809.146",
	"6.0.12": "76.0.3809.146",
	"6.1.0": "76.0.3809.146",
	"6.1.1": "76.0.3809.146",
	"6.1.2": "76.0.3809.146",
	"6.1.3": "76.0.3809.146",
	"6.1.4": "76.0.3809.146",
	"6.1.5": "76.0.3809.146",
	"6.1.6": "76.0.3809.146",
	"6.1.7": "76.0.3809.146",
	"6.1.8": "76.0.3809.146",
	"6.1.9": "76.0.3809.146",
	"6.1.10": "76.0.3809.146",
	"6.1.11": "76.0.3809.146",
	"6.1.12": "76.0.3809.146",
	"7.0.0-beta.1": "78.0.3866.0",
	"7.0.0-beta.2": "78.0.3866.0",
	"7.0.0-beta.3": "78.0.3866.0",
	"7.0.0-beta.4": "78.0.3896.6",
	"7.0.0-beta.5": "78.0.3905.1",
	"7.0.0-beta.6": "78.0.3905.1",
	"7.0.0-beta.7": "78.0.3905.1",
	"7.0.0-nightly.20190521": "76.0.3784.0",
	"7.0.0-nightly.20190529": "76.0.3806.0",
	"7.0.0-nightly.20190530": "76.0.3806.0",
	"7.0.0-nightly.20190531": "76.0.3806.0",
	"7.0.0-nightly.20190602": "76.0.3806.0",
	"7.0.0-nightly.20190603": "76.0.3806.0",
	"7.0.0-nightly.20190604": "77.0.3814.0",
	"7.0.0-nightly.20190605": "77.0.3815.0",
	"7.0.0-nightly.20190606": "77.0.3815.0",
	"7.0.0-nightly.20190607": "77.0.3815.0",
	"7.0.0-nightly.20190608": "77.0.3815.0",
	"7.0.0-nightly.20190609": "77.0.3815.0",
	"7.0.0-nightly.20190611": "77.0.3815.0",
	"7.0.0-nightly.20190612": "77.0.3815.0",
	"7.0.0-nightly.20190613": "77.0.3815.0",
	"7.0.0-nightly.20190615": "77.0.3815.0",
	"7.0.0-nightly.20190616": "77.0.3815.0",
	"7.0.0-nightly.20190618": "77.0.3815.0",
	"7.0.0-nightly.20190619": "77.0.3815.0",
	"7.0.0-nightly.20190622": "77.0.3815.0",
	"7.0.0-nightly.20190623": "77.0.3815.0",
	"7.0.0-nightly.20190624": "77.0.3815.0",
	"7.0.0-nightly.20190627": "77.0.3815.0",
	"7.0.0-nightly.20190629": "77.0.3815.0",
	"7.0.0-nightly.20190630": "77.0.3815.0",
	"7.0.0-nightly.20190701": "77.0.3815.0",
	"7.0.0-nightly.20190702": "77.0.3815.0",
	"7.0.0-nightly.20190704": "77.0.3843.0",
	"7.0.0-nightly.20190705": "77.0.3843.0",
	"7.0.0-nightly.20190719": "77.0.3848.0",
	"7.0.0-nightly.20190720": "77.0.3848.0",
	"7.0.0-nightly.20190721": "77.0.3848.0",
	"7.0.0-nightly.20190726": "77.0.3864.0",
	"7.0.0-nightly.20190727": "78.0.3866.0",
	"7.0.0-nightly.20190728": "78.0.3866.0",
	"7.0.0-nightly.20190729": "78.0.3866.0",
	"7.0.0-nightly.20190730": "78.0.3866.0",
	"7.0.0-nightly.20190731": "78.0.3866.0",
	"7.0.0": "78.0.3905.1",
	"7.0.1": "78.0.3904.92",
	"7.1.0": "78.0.3904.94",
	"7.1.1": "78.0.3904.99",
	"7.1.2": "78.0.3904.113",
	"7.1.3": "78.0.3904.126",
	"7.1.4": "78.0.3904.130",
	"7.1.5": "78.0.3904.130",
	"7.1.6": "78.0.3904.130",
	"7.1.7": "78.0.3904.130",
	"7.1.8": "78.0.3904.130",
	"7.1.9": "78.0.3904.130",
	"7.1.10": "78.0.3904.130",
	"7.1.11": "78.0.3904.130",
	"7.1.12": "78.0.3904.130",
	"7.1.13": "78.0.3904.130",
	"7.1.14": "78.0.3904.130",
	"7.2.0": "78.0.3904.130",
	"7.2.1": "78.0.3904.130",
	"7.2.2": "78.0.3904.130",
	"7.2.3": "78.0.3904.130",
	"7.2.4": "78.0.3904.130",
	"7.3.0": "78.0.3904.130",
	"7.3.1": "78.0.3904.130",
	"7.3.2": "78.0.3904.130",
	"8.0.0-beta.1": "79.0.3931.0",
	"8.0.0-beta.2": "79.0.3931.0",
	"8.0.0-beta.3": "80.0.3955.0",
	"8.0.0-beta.4": "80.0.3955.0",
	"8.0.0-beta.5": "80.0.3987.14",
	"8.0.0-beta.6": "80.0.3987.51",
	"8.0.0-beta.7": "80.0.3987.59",
	"8.0.0-beta.8": "80.0.3987.75",
	"8.0.0-beta.9": "80.0.3987.75",
	"8.0.0-nightly.20190801": "78.0.3866.0",
	"8.0.0-nightly.20190802": "78.0.3866.0",
	"8.0.0-nightly.20190803": "78.0.3871.0",
	"8.0.0-nightly.20190806": "78.0.3871.0",
	"8.0.0-nightly.20190807": "78.0.3871.0",
	"8.0.0-nightly.20190808": "78.0.3871.0",
	"8.0.0-nightly.20190809": "78.0.3871.0",
	"8.0.0-nightly.20190810": "78.0.3871.0",
	"8.0.0-nightly.20190811": "78.0.3871.0",
	"8.0.0-nightly.20190812": "78.0.3871.0",
	"8.0.0-nightly.20190813": "78.0.3871.0",
	"8.0.0-nightly.20190814": "78.0.3871.0",
	"8.0.0-nightly.20190815": "78.0.3871.0",
	"8.0.0-nightly.20190816": "78.0.3881.0",
	"8.0.0-nightly.20190817": "78.0.3881.0",
	"8.0.0-nightly.20190818": "78.0.3881.0",
	"8.0.0-nightly.20190819": "78.0.3881.0",
	"8.0.0-nightly.20190820": "78.0.3881.0",
	"8.0.0-nightly.20190824": "78.0.3892.0",
	"8.0.0-nightly.20190825": "78.0.3892.0",
	"8.0.0-nightly.20190827": "78.0.3892.0",
	"8.0.0-nightly.20190828": "78.0.3892.0",
	"8.0.0-nightly.20190830": "78.0.3892.0",
	"8.0.0-nightly.20190901": "78.0.3892.0",
	"8.0.0-nightly.20190902": "78.0.3892.0",
	"8.0.0-nightly.20190907": "78.0.3892.0",
	"8.0.0-nightly.20190909": "78.0.3892.0",
	"8.0.0-nightly.20190910": "78.0.3892.0",
	"8.0.0-nightly.20190911": "78.0.3892.0",
	"8.0.0-nightly.20190913": "78.0.3892.0",
	"8.0.0-nightly.20190914": "78.0.3892.0",
	"8.0.0-nightly.20190915": "78.0.3892.0",
	"8.0.0-nightly.20190917": "78.0.3892.0",
	"8.0.0-nightly.20190919": "79.0.3915.0",
	"8.0.0-nightly.20190920": "79.0.3915.0",
	"8.0.0-nightly.20190923": "79.0.3919.0",
	"8.0.0-nightly.20190924": "79.0.3919.0",
	"8.0.0-nightly.20190926": "79.0.3919.0",
	"8.0.0-nightly.20190929": "79.0.3919.0",
	"8.0.0-nightly.20190930": "79.0.3919.0",
	"8.0.0-nightly.20191001": "79.0.3919.0",
	"8.0.0-nightly.20191004": "79.0.3919.0",
	"8.0.0-nightly.20191005": "79.0.3919.0",
	"8.0.0-nightly.20191006": "79.0.3919.0",
	"8.0.0-nightly.20191009": "79.0.3919.0",
	"8.0.0-nightly.20191011": "79.0.3919.0",
	"8.0.0-nightly.20191012": "79.0.3919.0",
	"8.0.0-nightly.20191017": "79.0.3919.0",
	"8.0.0-nightly.20191019": "79.0.3931.0",
	"8.0.0-nightly.20191020": "79.0.3931.0",
	"8.0.0-nightly.20191021": "79.0.3931.0",
	"8.0.0-nightly.20191023": "79.0.3931.0",
	"8.0.0-nightly.20191101": "80.0.3952.0",
	"8.0.0-nightly.20191105": "80.0.3952.0",
	"8.0.0": "80.0.3987.86",
	"8.0.1": "80.0.3987.86",
	"8.0.2": "80.0.3987.86",
	"8.0.3": "80.0.3987.134",
	"8.1.0": "80.0.3987.137",
	"8.1.1": "80.0.3987.141",
	"8.2.0": "80.0.3987.158",
	"8.2.1": "80.0.3987.163",
	"8.2.2": "80.0.3987.163",
	"8.2.3": "80.0.3987.163",
	"8.2.4": "80.0.3987.165",
	"8.2.5": "80.0.3987.165",
	"8.3.0": "80.0.3987.165",
	"8.3.1": "80.0.3987.165",
	"8.3.2": "80.0.3987.165",
	"8.3.3": "80.0.3987.165",
	"8.3.4": "80.0.3987.165",
	"8.4.0": "80.0.3987.165",
	"8.4.1": "80.0.3987.165",
	"8.5.0": "80.0.3987.165",
	"9.0.0-beta.1": "82.0.4048.0",
	"9.0.0-beta.2": "82.0.4048.0",
	"9.0.0-beta.3": "82.0.4048.0",
	"9.0.0-beta.4": "82.0.4048.0",
	"9.0.0-beta.5": "82.0.4048.0",
	"9.0.0-beta.6": "82.0.4058.2",
	"9.0.0-beta.7": "82.0.4058.2",
	"9.0.0-beta.9": "82.0.4058.2",
	"9.0.0-beta.10": "82.0.4085.10",
	"9.0.0-beta.12": "82.0.4085.14",
	"9.0.0-beta.13": "82.0.4085.14",
	"9.0.0-beta.14": "82.0.4085.27",
	"9.0.0-beta.15": "83.0.4102.3",
	"9.0.0-beta.16": "83.0.4102.3",
	"9.0.0-beta.17": "83.0.4103.14",
	"9.0.0-beta.18": "83.0.4103.16",
	"9.0.0-beta.19": "83.0.4103.24",
	"9.0.0-beta.20": "83.0.4103.26",
	"9.0.0-beta.21": "83.0.4103.26",
	"9.0.0-beta.22": "83.0.4103.34",
	"9.0.0-beta.23": "83.0.4103.44",
	"9.0.0-beta.24": "83.0.4103.45",
	"9.0.0-nightly.20191121": "80.0.3954.0",
	"9.0.0-nightly.20191122": "80.0.3954.0",
	"9.0.0-nightly.20191123": "80.0.3954.0",
	"9.0.0-nightly.20191124": "80.0.3954.0",
	"9.0.0-nightly.20191129": "80.0.3954.0",
	"9.0.0-nightly.20191130": "80.0.3954.0",
	"9.0.0-nightly.20191201": "80.0.3954.0",
	"9.0.0-nightly.20191202": "80.0.3954.0",
	"9.0.0-nightly.20191203": "80.0.3954.0",
	"9.0.0-nightly.20191204": "80.0.3954.0",
	"9.0.0-nightly.20191210": "80.0.3954.0",
	"9.0.0-nightly.20191220": "81.0.3994.0",
	"9.0.0-nightly.20191221": "81.0.3994.0",
	"9.0.0-nightly.20191222": "81.0.3994.0",
	"9.0.0-nightly.20191223": "81.0.3994.0",
	"9.0.0-nightly.20191224": "81.0.3994.0",
	"9.0.0-nightly.20191225": "81.0.3994.0",
	"9.0.0-nightly.20191226": "81.0.3994.0",
	"9.0.0-nightly.20191228": "81.0.3994.0",
	"9.0.0-nightly.20191229": "81.0.3994.0",
	"9.0.0-nightly.20191230": "81.0.3994.0",
	"9.0.0-nightly.20191231": "81.0.3994.0",
	"9.0.0-nightly.20200101": "81.0.3994.0",
	"9.0.0-nightly.20200103": "81.0.3994.0",
	"9.0.0-nightly.20200104": "81.0.3994.0",
	"9.0.0-nightly.20200105": "81.0.3994.0",
	"9.0.0-nightly.20200106": "81.0.3994.0",
	"9.0.0-nightly.20200108": "81.0.3994.0",
	"9.0.0-nightly.20200109": "81.0.3994.0",
	"9.0.0-nightly.20200110": "81.0.3994.0",
	"9.0.0-nightly.20200111": "81.0.3994.0",
	"9.0.0-nightly.20200113": "81.0.3994.0",
	"9.0.0-nightly.20200115": "81.0.3994.0",
	"9.0.0-nightly.20200116": "81.0.3994.0",
	"9.0.0-nightly.20200117": "81.0.3994.0",
	"9.0.0-nightly.20200119": "81.0.4030.0",
	"9.0.0-nightly.20200121": "81.0.4030.0",
	"9.0.0": "83.0.4103.64",
	"9.0.1": "83.0.4103.94",
	"9.0.2": "83.0.4103.94",
	"9.0.3": "83.0.4103.100",
	"9.0.4": "83.0.4103.104",
	"9.0.5": "83.0.4103.119",
	"9.1.0": "83.0.4103.122",
	"9.1.1": "83.0.4103.122",
	"9.1.2": "83.0.4103.122",
	"9.2.0": "83.0.4103.122",
	"9.2.1": "83.0.4103.122",
	"10.0.0-beta.1": "84.0.4129.0",
	"10.0.0-beta.2": "84.0.4129.0",
	"10.0.0-beta.3": "85.0.4161.2",
	"10.0.0-beta.4": "85.0.4161.2",
	"10.0.0-beta.8": "85.0.4181.1",
	"10.0.0-beta.9": "85.0.4181.1",
	"10.0.0-beta.10": "85.0.4183.19",
	"10.0.0-beta.11": "85.0.4183.20",
	"10.0.0-beta.12": "85.0.4183.26",
	"10.0.0-beta.13": "85.0.4183.39",
	"10.0.0-beta.14": "85.0.4183.39",
	"10.0.0-beta.15": "85.0.4183.39",
	"10.0.0-beta.17": "85.0.4183.39",
	"10.0.0-beta.19": "85.0.4183.39",
	"10.0.0-beta.20": "85.0.4183.39",
	"10.0.0-beta.21": "85.0.4183.39",
	"10.0.0-beta.23": "85.0.4183.70",
	"10.0.0-nightly.20200209": "82.0.4050.0",
	"10.0.0-nightly.20200210": "82.0.4050.0",
	"10.0.0-nightly.20200211": "82.0.4050.0",
	"10.0.0-nightly.20200216": "82.0.4050.0",
	"10.0.0-nightly.20200217": "82.0.4050.0",
	"10.0.0-nightly.20200218": "82.0.4050.0",
	"10.0.0-nightly.20200221": "82.0.4050.0",
	"10.0.0-nightly.20200222": "82.0.4050.0",
	"10.0.0-nightly.20200223": "82.0.4050.0",
	"10.0.0-nightly.20200226": "82.0.4050.0",
	"10.0.0-nightly.20200303": "82.0.4050.0",
	"10.0.0-nightly.20200304": "82.0.4076.0",
	"10.0.0-nightly.20200305": "82.0.4076.0",
	"10.0.0-nightly.20200306": "82.0.4076.0",
	"10.0.0-nightly.20200309": "82.0.4076.0",
	"10.0.0-nightly.20200310": "82.0.4076.0",
	"10.0.0-nightly.20200311": "82.0.4083.0",
	"10.0.0-nightly.20200316": "83.0.4086.0",
	"10.0.0-nightly.20200317": "83.0.4087.0",
	"10.0.0-nightly.20200318": "83.0.4087.0",
	"10.0.0-nightly.20200320": "83.0.4087.0",
	"10.0.0-nightly.20200323": "83.0.4087.0",
	"10.0.0-nightly.20200324": "83.0.4087.0",
	"10.0.0-nightly.20200325": "83.0.4087.0",
	"10.0.0-nightly.20200326": "83.0.4087.0",
	"10.0.0-nightly.20200327": "83.0.4087.0",
	"10.0.0-nightly.20200330": "83.0.4087.0",
	"10.0.0-nightly.20200331": "83.0.4087.0",
	"10.0.0-nightly.20200401": "83.0.4087.0",
	"10.0.0-nightly.20200402": "83.0.4087.0",
	"10.0.0-nightly.20200403": "83.0.4087.0",
	"10.0.0-nightly.20200406": "83.0.4087.0",
	"10.0.0-nightly.20200408": "83.0.4095.0",
	"10.0.0-nightly.20200410": "83.0.4095.0",
	"10.0.0-nightly.20200413": "83.0.4095.0",
	"10.0.0-nightly.20200414": "84.0.4114.0",
	"10.0.0-nightly.20200415": "84.0.4115.0",
	"10.0.0-nightly.20200416": "84.0.4115.0",
	"10.0.0-nightly.20200417": "84.0.4115.0",
	"10.0.0-nightly.20200422": "84.0.4121.0",
	"10.0.0-nightly.20200423": "84.0.4121.0",
	"10.0.0-nightly.20200427": "84.0.4125.0",
	"10.0.0-nightly.20200428": "84.0.4125.0",
	"10.0.0-nightly.20200429": "84.0.4125.0",
	"10.0.0-nightly.20200430": "84.0.4125.0",
	"10.0.0-nightly.20200501": "84.0.4129.0",
	"10.0.0-nightly.20200504": "84.0.4129.0",
	"10.0.0-nightly.20200505": "84.0.4129.0",
	"10.0.0-nightly.20200506": "84.0.4129.0",
	"10.0.0-nightly.20200507": "84.0.4129.0",
	"10.0.0-nightly.20200508": "84.0.4129.0",
	"10.0.0-nightly.20200511": "84.0.4129.0",
	"10.0.0-nightly.20200512": "84.0.4129.0",
	"10.0.0-nightly.20200513": "84.0.4129.0",
	"10.0.0-nightly.20200514": "84.0.4129.0",
	"10.0.0-nightly.20200515": "84.0.4129.0",
	"10.0.0-nightly.20200518": "84.0.4129.0",
	"10.0.0-nightly.20200519": "84.0.4129.0",
	"10.0.0-nightly.20200520": "84.0.4129.0",
	"10.0.0-nightly.20200521": "84.0.4129.0",
	"11.0.0-nightly.20200525": "84.0.4129.0",
	"11.0.0-nightly.20200526": "84.0.4129.0",
	"11.0.0-nightly.20200529": "85.0.4156.0",
	"11.0.0-nightly.20200602": "85.0.4162.0",
	"11.0.0-nightly.20200603": "85.0.4162.0",
	"11.0.0-nightly.20200604": "85.0.4162.0",
	"11.0.0-nightly.20200609": "85.0.4162.0",
	"11.0.0-nightly.20200610": "85.0.4162.0",
	"11.0.0-nightly.20200611": "85.0.4162.0",
	"11.0.0-nightly.20200615": "85.0.4162.0",
	"11.0.0-nightly.20200616": "85.0.4162.0",
	"11.0.0-nightly.20200617": "85.0.4162.0",
	"11.0.0-nightly.20200618": "85.0.4162.0",
	"11.0.0-nightly.20200619": "85.0.4162.0",
	"11.0.0-nightly.20200701": "85.0.4179.0",
	"11.0.0-nightly.20200702": "85.0.4179.0",
	"11.0.0-nightly.20200703": "85.0.4179.0",
	"11.0.0-nightly.20200706": "85.0.4179.0",
	"11.0.0-nightly.20200707": "85.0.4179.0",
	"11.0.0-nightly.20200708": "85.0.4179.0",
	"11.0.0-nightly.20200709": "85.0.4179.0",
	"11.0.0-nightly.20200716": "86.0.4203.0",
	"11.0.0-nightly.20200717": "86.0.4203.0",
	"11.0.0-nightly.20200720": "86.0.4203.0",
	"11.0.0-nightly.20200721": "86.0.4203.0",
	"11.0.0-nightly.20200723": "86.0.4209.0",
	"11.0.0-nightly.20200724": "86.0.4209.0",
	"11.0.0-nightly.20200729": "86.0.4209.0",
	"11.0.0-nightly.20200730": "86.0.4209.0",
	"11.0.0-nightly.20200731": "86.0.4209.0",
	"11.0.0-nightly.20200803": "86.0.4209.0",
	"11.0.0-nightly.20200804": "86.0.4209.0",
	"11.0.0-nightly.20200805": "86.0.4209.0",
	"11.0.0-nightly.20200811": "86.0.4209.0",
	"11.0.0-nightly.20200812": "86.0.4209.0"
};